<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>IsometricGridOff</name>
    <message>
        <location filename="../IsometricGridOff.js" line="+35"/>
        <source>Isometric Grid &amp;Off</source>
        <translation>Izometrická mřížka &amp;vypnuta</translation>
    </message>
</context>
</TS>
